/*
 * The Kibitz - Config and Init
 *
 * (c) 2005-2012 Tomas Valla <tom@ucw.cz>
 *
 * This software may be freely distributed and used according to the terms
 * of the GNU Lesser General Public License. See COPYING for details.
 */

#include <kibitz/lib.h>
#include <ucw/conf.h>
#include <ucw/getopt.h>
#include <kibitz/internal.h>

struct config config;

static struct cf_section kibitz_section = {
#define F(x) &config.x
	CF_ITEMS {
		CF_STRING("LogFile", F(indexer_log_file)),
		CF_UNS("Verbose", F(indexer_verbose)),
		CF_UNS("MinWordLen", F(min_word_len)),
		CF_UNS("MaxWordLen", F(max_word_len)),
		CF_UNS("MinPhraseLen", F(min_phrase_len)),
		CF_UNS("MaxPhraseLen", F(max_phrase_len)),
		CF_UNS("FastFindThreshold", F(fastfind_threshold)),
		CF_UNS("FastFindItems", F(fastfind_items)),
		CF_UNS("DefaultWordRefBufSize", F(default_wordref_buf_size)),

		CF_UNS("QueryMaxResults", F(query_max_results)),

		CF_DOUBLE("ExactMatchBonus", F(exact_match_bonus)),
		CF_DOUBLE("SingleWordBonus", F(single_word_bonus)),
		CF_DOUBLE("PhraseBonus", F(phrase_bonus)),

		CF_STRING("StatusFile", F(httpd_status_file)),
		CF_STRING("LogFile", F(httpd_log_file)),
		CF_UNS("ListenQueue", F(listen_queue)),
		CF_UNS("LogConnections", F(log_connections)),
		CF_UNS("RequestTimeout", F(request_timeout)),
		CF_UNS("ResponseTimeout", F(response_timeout)),
		CF_UNS("Port", F(httpd_port)),

		CF_END
	}
#undef F
};

static void CONSTRUCTOR kibitz_preinit(void)
{
	cf_declare_section("Kibitz", &kibitz_section, 0);

	config.indexer_log_file = NULL;
	config.indexer_verbose = 0;
	config.min_word_len = 2;
	config.max_word_len = HARD_MAX_WORD_LEN;
	config.min_phrase_len = 2;
	config.max_phrase_len = HARD_MAX_PHRASE_LEN;
	config.fastfind_threshold = 100;
	config.fastfind_items = HARD_FASTFIND_ITEMS;
	config.default_wordref_buf_size = 100000;

	config.exact_match_bonus = 1;
	config.single_word_bonus = 1;
	config.phrase_bonus = 1;

	config.query_max_results = 20;

	config.httpd_status_file = NULL;
	config.httpd_log_file = NULL;
	config.listen_queue = 50;
	config.log_connections = 1;
	config.request_timeout = 5000;
	config.response_timeout = 5000;
	config.httpd_port = 3333;
}

void kibitz_init(byte *cfg_file)
{
	cf_def_file = INSTALL_CONFIG_DIR "/kibitz";
	if (cfg_file)
		cf_def_file = cfg_file;

	ASSERT(config.max_word_len <= HARD_MAX_WORD_LEN);
	ASSERT(config.max_phrase_len <= HARD_MAX_PHRASE_LEN);
	ASSERT(config.fastfind_items <= HARD_FASTFIND_ITEMS);
	ASSERT(config.query_max_results <= HARD_QUERY_MAX_RESULTS);
	ASSERT(config.default_wordref_buf_size > 0);
}

void kibitz_cleanup(void)
{
}
